.pagination-page-info {
    padding: .6em;
    padding-left: 0;
    width: 40em;
    margin: .5em;
    margin-left: 0;
    font-size: 12px;
}
.pagination-page-info b {
    color: black;
    background: #6aa6ed;
    padding-left: 2px;
    padding: .1em .25em;
    font-size: 150%;
}
.ui-widget-content a {
    color: #3399f3;
    text-decoration: none;
    background-color: transparent;
}
.ui-widget-content a:hover {
  color: #0c73cd;
  text-decoration: underline;
}
