# coding: utf-8

from __future__ import absolute_import

from flask import json
from six import BytesIO

from swagger_server.test import BaseTestCase


class TestTagsController(BaseTestCase):
    """TagsController integration test stubs"""

    def test_tags_count_get(self):
        """Test case for tags_count_get

        Get number of tags present in MDB
        """
        response = self.client.open(
            '/v1/tags/count',
            method='GET')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_tags_get(self):
        """Test case for tags_get

        Get all tag nodes in MDB
        """
        response = self.client.open(
            '/v1/tags',
            method='GET')
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    import unittest
    unittest.main()
