{% extends "base.html" %}

{% block app_content %}
    <h1>{{ 'An unexpected error has occurred' }}</h1>
    <p>{{ 'Sorry for the inconvenience!' }}</p>
    <p><a href="{{ url_for('main.index') }}">{{ 'Back' }}</a></p>
{% endblock %}
