def pvs_synonyms_model_version_get(modelHandle, modelVersion):
    """
    Get Permissible Values and Synonyms for a specified model and version.

    :param modelHandle: Handle of model (use /models to find available handles)
    :type modelHandle: str
    :param modelVersion: Version of model (use /models to find available versions)
    :type modelVersion: str

    :rtype: object
    """
    return "do some magic!"


def cde_pvs_by_id_with_version_get(id, version):
    """
    Get PVs for a given CDE id and version.

    :param id: CDE ID
    :type id: str
    :param version: CDE Version
    :type version: str

    :rtype: object
    """
    return "do some magic!"


def term_by_origin_with_version_get(origin_name, origin_id, origin_version):
    """
    Get term by origin, origin_id, and origin_version.

    :param origin_name: Origin Name
    :type origin_name: str
    :param origin_id: Origin ID
    :type origin_id: str
    :param origin_version: Origin Version
    :type origin_version: str

    :rtype: object
    """
    return "do some magic!"
