<h4>Metamodel Database (MDB)</h4>
The MDB is a graph database that records
    <ul>
        <li>The Node/Relationship/Property structure of data models across a set of systems or repositories;</li>
        <li>Terms, i.e., controlled vocabulary, employed in the backend data systems that the models represent;</li>
        <li>Synonyms for vocabulary mapped between models or from external standards; and,</li>
        <li>Acceptable Value Sets of Terms for Properties having enumerated value domains, and data types for other properties.</li>
    </ul>

    The MDB is intended to provide an up-to-date view across data models for an integrated system of data repositories. Some use cases include:
    <ul>
      <li> Auditing and maintenance of data model changes and updates; </li>
      <li> Storage of synonym mappings among entities and terminology from different models; </li>
      <li> Detailed searching across large models and sets of terminology; </li>
      <li> Exploration of model structure for QA of within- and between-model consistency and accuracy of vocabulary; </li>
      <li> Enabling automated transformation of data between different models via stored synonym, hierarchical, and other mappings; </li>
      <li> Providing a single resource for viewing and evaluating existing data models in a system, for model reuse or new model design. </li>
    </ul>

    More details about the structure and rationale behind the MDB <a href="https://cbiit.github.io/bento-meta">is available.</a> 
